.. Abjad documentation master file, created by
    sphinx-quickstart on Tue Apr 14 22:09:19 2009.
    You can adapt this file completely to your liking, 
    but it should at least contain the root `toctree` directive.

Welcome to Abjad (|release|)
=============================

.. only:: html

    Abjad helps composers build up complex pieces of music notation
    in an iterative and incremental way. 
    Use Abjad to create a symbolic representation of all the notes, 
    rests, staves, tuplets, beams and slurs in any score.
    Because Abjad extends the Python programming language,
    you can use Abjad to make systematic changes to your music as you work.
    And because Abjad wraps the powerful LilyPond music notation package,
    you can use Abjad to control the typographic details of the symbols on the 
    page.

    .. image:: examples/ferneyhough/images/ferneyhough.png

.. only:: html or latex

   .. toctree::

      start_here/index
      system_overview/index
      examples/index
      tutorials/index
      reference_manual/index
      developer_documentation/index
      in_conversation/index
      appendices/index

.. only:: html

   .. toctree::

      api/index
